#
# spec file for package mkfontscale
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mkfontscale
Version:        1.2.3
Release:        1.5
Summary:        Utility to create index of scalable font files for X
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(fontenc)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.25
Recommends:     xorg-x11-fonts-core
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
Provides:       mkfontdir = 1.0.7
Obsoletes:      mkfontdir <= 1.0.7

%description
mkfontscale creates the fonts.scale and fonts.dir index files used by the
legacy X11 font system.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/mkfontdir
%{_bindir}/mkfontscale
%{_mandir}/man1/mkfontdir.1%{?ext_man}
%{_mandir}/man1/mkfontscale.1%{?ext_man}

%changelog
* Mon Mar  4 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.3
  * configure: Use pkg-config to find zlib
  * configure: Use AC_SYS_LARGEFILE to enable large file support
  * gitlab CI: stop requiring Signed-off-by in commits
  * Remove "All rights reserved" from Oracle copyright notices
  * Convert to X.Org standard code style
  * doDirectory: add missing check for malloc() returning NULL
  * mkfontscale.c: handle -Wshadow warnings from gcc
  * ident.c: clear -Wdeclaration-after-statement warning
  * Variable scope reductions as recommended by cppcheck
  * Resolve some -Wsign-conversion warnings from clang
  * Fix -Wimplicit-float-conversion warnings from clang
  * configure: Move check for zlib into its own section
  * Address a UBSan warning about int left shift overflow
* Sun Apr  3 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.2
  * bugfix release
* Fri Mar 12 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move license to licensedir)
* Fri Mar 22 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.1
  * This release fixes a regression introduced in the 1.2.0
    release that could leave the mkfontdir script containing
    an unexpanded reference to ${exec_prefix} as shown in
    https://gitlab.freedesktop.org/xorg/app/mkfontscale/issues/5
* Sun Mar  3 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.0
  * Starting with this release, 1.2.0, it now includes the
    mkfontdir script previously distributed separately for
    compatibility with older X11 versions.
- provide/obsolete mkfontdir package
* Mon Sep 10 2018 sndirsch@suse.com
- recommends xorg-x11-fonts-core package, so an approprite
  encodings.dir file can be written to each font directory
  (boo#1106850)
* Wed Mar  7 2018 sndirsch@suse.com
- Update to version 1.1.3:
  * autogen.sh: use quoted string variables
  * mkfontscale: Avoid a buffer underrun
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
  * fix handling of Type1 fonts without /FamilyName and/or /FullName
- supersedes u_mkfontscale-fix-handling-of-Type1-fonts-without-FamilyName-and-o.patch
* Tue Mar  3 2015 pgajdos@suse.com
- fix segfault for Hershey fonts [bnc#918466]
- treat /FontName as family name when /FamilyName is missing
  + u_mkfontscale-fix-handling-of-Type1-fonts-without-FamilyName-and-o.patch
* Mon Feb  2 2015 zaitor@opensuse.org
- Update to version 1.1.2:
  + Remove extraneous duplicate checks for -r & -n options.
  + autogen.sh: Honor NOCONFIGURE=1.
  + configure: Drop AM_MAINTAINER_MODE.
  + Only include config.h if it exists.
  + Fix possible malloc allocation error found by clang static
    analysis.
  + Plug a memory leak found by clang static analysis.
  + Print which option was in error along with usage message.
  + Make usage() always exit(1).
  + Add -v flag to print program version.
  + Add missing newline to usage output.
* Sat Aug 17 2013 zaitor@opensuse.org
- Update to version 1.1.1:
  + Protect config.h inclusion like usual.
  + Document -u/-U options in man page.
  + Replace malloc(strlen);strcpy() calls with strdup.
  + Since hash() returns unsigned int, store results in unsigned
    ints.
  + Fix compilation for MinGW.
  + Prefer original file over symlink (v2).
- Drop mkfontscale-skip_symlinks.diff, fixed upstream.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.1.0:
  + mkfontscale: fix Culmus entries to precede URW
  + Add Culmus foundry to the vendor list for TrueType & Type1
    fonts
  + Add const attributes to fix gcc -Wwrite-strings warnings
  + Mark format string argument to dsprintf as const char *
  + mkfontscale: Support FontForge weight designations.
- Changes from version 1.0.9:
  + Add _X_ATTRIBUTE_PRINTF to functions taking printf format
    arguments
  + makeList: free partially allocated list on failure
  + Leave room for null terminator in file & font name arrays
  + Sort contents of encodings.dir
  + Remove unused NEED_SNPRINTF code to #include non-existent
    snprintf.c
  + Make fscanf format string constant so it can be checked at
    compile time
  + Man page fixes.
  + Build system fixes.
* Fri Apr 13 2012 vuntz@opensuse.org
- Update mkfontscale-skip_symlinks.diff to use realpath() instead
  of the GNU-specific canonicalize_file_name().
* Fri Apr 13 2012 vuntz@opensuse.org
- Split mkfontscale from xorg-x11. Initial version: 1.0.8.
